README.md
Это библиотека с датами посадки сельско-хозяйственных культур для моей бабушки.
По мере обновления в библиотеке будут появлятся и новые овощи, и она будет становится более универсальной.
Пока что все файлы кроме year_2024.py и __init__.py и months.py не используются.
Используется MIT License.